indexing
	description: "Ficiticious application to demonstrate the use of the command line parsing library"
	author: "Bernd Schoeller"
	copyright: "(c) 2006 Bernd Schoeller (bernd@fams.de)"
	license: "see included README.txt file"
	date: "$Date: 2006/03/27 08:22:34 $"
	revision: "$Revision: 1.3 $"

class OPTEST

create

	make

feature {NONE} -- Initialization 

	make is
			-- Run the application with options.
		do
			-- Create the parser
			create parser.make

			-- We need at least one non-option argument (parameter)
			parser.set_required_parameters (1)
			parser.set_parameters_description ("file ...")

			-- Set up verbose flag
			create verbose_flag.make ('v',"verbose")
			verbose_flag.set_description ("Increase the level of verbosity (may be specified multiple times).")
			parser.extend (verbose_flag)

			-- Set up the debug mode option
			create debug_mode_option.make ('d',"debug")
			debug_mode_option.set_description ("Enable or disable debug mode for the option.")
			parser.extend (debug_mode_option)

			-- Set up the 'number of users' option
			create number_of_users_option.make_with_short_form ('n')
			number_of_users_option.set_description ("Number of users.")
			parser.extend (number_of_users_option)

			-- Set up the define option
			create define_option.make ('D',"define")
			define_option.set_description ("Add a definition to the execution.")
			define_option.set_parameter_description ("%"name=value%"")
			parser.extend (define_option)

			-- Set up the compile option
			create compiler_option.make_with_long_form ("compiler")
			compiler_option.set_description ("Select the compiler to use.")
			compiler_option.extend ("gcc")
			compiler_option.extend ("msc")
			compiler_option.extend ("bcb")
			parser.extend (compiler_option)
						
			-- Do the actual work
			parser.parse_arguments

			-- Print the results
			print ("Results from command line parsing:%N")
			print ("The verbosity level is "+verbose_flag.occurrences.out+"%N")
			if debug_mode_option.was_found then
				if debug_mode_option.is_true then
					print ("Debug Mode has been enabled.%N")
				else
					print ("Debug Mode has been disabled.%N")
				end
			end
			if number_of_users_option.was_found then
				print ("Number of specified users: "+number_of_users_option.parameter.out+"%N")
			end
			from
				define_option.parameters.start
			until
				define_option.parameters.off
			loop
				print ("Supplied Definitions: "+define_option.parameters.item_for_iteration+"%N")
				define_option.parameters.forth
			end
			if compiler_option.was_found then
				print ("The selected compiler was: "+compiler_option.parameter+"%N")
			end
		end

feature -- Command Line Options

	verbose_flag: OP_FLAG
			-- Flag if the application should be verbose

	debug_mode_option: OP_BOOLEAN_OPTION
			-- Option if the application should run in debug mode

	number_of_users_option: OP_INTEGER_OPTION
			-- Times the application should repeat the operation
	
	define_option: OP_STRING_OPTION
			-- Add a definition to the application

	compiler_option: OP_ENUMERATION_OPTION
			-- Compiler to use

feature {NONE} -- Implementation

	parser: OP_PARSER
			-- Command line parser
	
end
	
