indexing
	description: "Errors that can occure during argument parsing"
	author: "Bernd Schoeller"
	copyright: "(c) 2006 Bernd Schoeller (bernd@fams.de)"
	license: "see included README.txt file"
	date: "$Date: 2006/03/25 10:13:50 $"
	revision: "$Revision: 1.1 $"

class OP_ERROR

inherit
	
	UT_ERROR
	
create

	make_unknown_option_error, make_missing_parameter_error,
	make_unnecessary_parameter_error, make_invalid_parameter_error,
	make_not_enough_parameters

feature {NONE} -- Initialization

	make_invalid_parameter_error (an_option: OP_OPTION; a_string:STRING) is
			-- The option `an_option' was supplied with an invalid parameter `a_string'.
		require
			option_not_void: an_option /= Void
			string_not_void: a_string /= Void
		do
			create parameters.make (1, 2)
			parameters.put (an_option.name, 1)
			parameters.put (a_string, 2)
			default_template := invalid_parameter_error_template
			code := invalid_parameter_error_code
		end
		
	make_missing_parameter_error (an_option: OP_OPTION) is
			-- The option `an_option' was missing a needed parameter.
		require
			not_void: an_option /= Void
		do
			create parameters.make (1, 1)
			parameters.put (an_option.name, 1)
			default_template := missing_parameter_error_template
			code := missing_parameter_error_code			
		end
		
	make_not_enough_parameters (found: INTEGER; required: INTEGER) is		
			-- The parser just found `found' parameters, while `required' are needed.
		require
			found_positive: found >= 0
			required_larger: required > found
		do
			create parameters.make (1, 2)
			parameters.put (found.out,1)
			parameters.put (required.out,2)
			default_template := not_enough_parameters_template
			code := not_enough_parameters_code
		end
		
	make_unknown_option_error (a_string: STRING) is
			-- A non-existing option `a_string' was requested.
		require
			not_void: a_string /= Void
		do
			create parameters.make (1, 1)
			parameters.put (a_string, 1)
			default_template := unknown_option_error_template
			code := unknown_option_error_code
		end
		
	make_unnecessary_parameter_error (an_option: OP_OPTION; a_string:STRING) is
			-- The option `an_option' was supplied with an unnecessary parameter `a_string'.
		require
			option_not_void: an_option /= Void
			string_not_void: a_string /= Void
		do
			create parameters.make (1, 2)
			parameters.put (an_option.name, 1)
			parameters.put (a_string, 2)
			default_template := unnecessary_parameter_error_template
			code := unnecessary_parameter_error_code
		end
		
feature -- Templates

	default_template: STRING
		-- Default template
		
	invalid_parameter_error_template: STRING is "The value '$2' is not valid for the option '$1'."
	missing_parameter_error_template: STRING is "The option '$1' is missing a parameter."
	not_enough_parameters_template: STRING is "Too few parameters ($1 found, $2 required)."
	unknown_option_error_template: STRING is "Unknown option '$1'."
	unnecessary_parameter_error_template: STRING is "The flag '$1' was given the parameter '$2'."
	
feature -- Error Codes

	code:STRING
		-- Error code
		
	invalid_parameter_error_code: STRING is "IPAR"
	missing_parameter_error_code: STRING is "MPAR"
	not_enough_parameters_code: STRING is "NEPAR"
	unknown_option_error_code: STRING is "UOPT"
	unnecessary_parameter_error_code: STRING is "UPAR"
	
invariant

	code_not_void: code /= Void	
	default_template_not_void: default_template /= Void

end
