indexing
	description: "Options that are not flags and need a parameter"
	author: "Bernd Schoeller"
	copyright: "(c) 2006 Bernd Schoeller (bernd@fams.de)"
	license: "see included README.txt file"
	date: "$Date: 2006/03/27 08:22:34 $"
	revision: "$Revision: 1.3 $"

deferred class OP_OPTION_WITH_PARAMETER [G]

inherit
	
	OP_OPTION
		redefine
			initialize,
			example,
			names
		end
		
feature {NONE} -- Initialization

	initialize is
			-- Perform the common initialization steps
		do
			Precursor {OP_OPTION}
			parameter_description := "arg"
		end

feature -- Access
	
	example: STRING is
			-- Example for the usage of the option
		do
			if has_short_form then
				Result := "["+short_option_introduction.out+short_form.out+" "+parameter_description+"]"
			else
				Result := "["+short_option_introduction.out+long_option_introduction.out+long_form+
					long_option_parameter_introduction.out+parameter_description+"]"
			end			
		end
	
	names: STRING is
			-- Names of the option (short and long)
		do
			Result := Precursor {OP_OPTION}
			if has_long_form then
				Result.append (long_option_parameter_introduction.out)
			else
				Result.append (" ")			
			end
			Result.append (parameter_description)
		end

	parameter_description: STRING
		-- Name of the parameter

	parameter: G is
			-- Last value give to the option
		require
			was_found: was_found
		do
			Result := parameters.last
		end

	parameters: DS_LIST [G] is
		-- All parameters given to the option
		deferred
		end

	occurrences: INTEGER is
			-- Number of times this flag was encountered
		do
			Result := parameters.count
		end	
				
feature -- Status report

	needs_parameter: BOOLEAN is
			-- Does this option need a parameter ?
		do
			Result := True
		end
		
feature -- Status setting

	set_parameter_description (a_string: STRING) is
			-- Set the parameter name to `a_string'.
		require
			not_void: a_string /= VOid
		do
			parameter_description := a_string
		ensure
			parameter_set: parameter_description = a_string
		end

invariant
	
	options_needs_parameter: needs_parameter
	parameters_exist: parameters /= Void

end
